@@ -27,7 +27,7 @@ from tiddlyweb.store import (NoBagError, NoRecipeError, NoTiddlerError,
 from tiddlyweb.stores import StorageInterface
 from tiddlyweb.util import binary_tiddler
 
-__version__ = '3.0.2'
+__version__ = '3.0.3'
 
 #logging.basicConfig()
 #logging.getLogger('sqlalchemy.engine').setLevel(logging.INFO)
@@ -161,7 +161,7 @@ class sRevision(Base):
 class sTiddler(Base):
     __tablename__ = 'tiddler'
     __table_args__ = (
-            UniqueConstraint('id', 'title', 'bag'),)
+            UniqueConstraint('title', 'bag'),)
 
     id = Column(Integer,
             primary_key=True,
